Coverage for girder/utility/dev_endpoints: 56%

# Coverage for girder/utility/dev_endpoints : 56%

## 9 statements 5 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 | #!/usr/bin/env python # -*- coding: utf-8 -*- ############################################################################### # Copyright 2013 Kitware Inc. # # Licensed under the Apache License, Version 2.0 ( the "License" ); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. ############################################################################### import cherrypy class PyCoverage(object): """ This endpoint serves the coverage.py HTML result report for tests run against this instance. """ exposed = True def GET(self): raise cherrypy.HTTPRedirect('/py_coverage/index.html') def addDevEndpoints(node, conf): """ This function should add any endpoints which should only be served in a development environment. """ node.py_coverage = PyCoverage() conf['/py_coverage'] = { 'tools.staticdir.on': 'True', 'tools.staticdir.dir': 'clients/web/dev/built/py_coverage' } return node, conf